<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://makewebbetter.com
 * @since      1.0.0
 *
 * @package    Woocommerce_What_Are_You_Looking_For
 * @subpackage Woocommerce_What_Are_You_Looking_For/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Woocommerce_What_Are_You_Looking_For
 * @subpackage Woocommerce_What_Are_You_Looking_For/admin
 * @author     MakeWebBetter <webmaster@makewebbetter.com>
 */
class Woocommerce_What_Are_You_Looking_For_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Woocommerce_What_Are_You_Looking_For_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Woocommerce_What_Are_You_Looking_For_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/woocommerce-what-are-you-looking-for-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Woocommerce_What_Are_You_Looking_For_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Woocommerce_What_Are_You_Looking_For_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/woocommerce-what-are-you-looking-for-admin.js', array( 'jquery' ), $this->version, false );
		wp_localize_script( $this->plugin_name, 'mwb_wwaylf_dir_url',MWB_WWAYLF_URL );

	}


	/**
	 * This Function is used to add setting menu
	 *
	 * @since    1.0.0
	 * @name mwb_wwaylf_admin_menu
	 */
	public function mwb_wwaylf_admin_menu()
	{
		add_submenu_page('woocommerce',__('WooCommerce What Are You Looking For','woocommerce-what-are-you-looking-for'),__('Woo What Are You Looking For','woocommerce-what-are-you-looking-for'),'manage_woocommerce','mwb_what_are_looking_for',array($this,'mwb_wwaylf_admin_setting'));
	}


	/**
	 * This Function is used to include html file for admin menu 
	 *
	 * @since    1.0.0
	 * @name mwb_wwaylf_admin_setting
	 */
	public function mwb_wwaylf_admin_setting()
	{
		include_once(MWB_WWAYLF_DIRPATH.'admin/partials/woocommerce-what-are-you-looking-for-admin-display.php');
	}

	/**
	 * This Function is used to save option values
	 *
	 * @since    1.0.0
	 * @name mwb_wwaylf_register_setting
	 */
	public function mwb_wwaylf_register_setting()
	{
		register_setting('mwb_wwaylf_general_setting','mwb_wwaylf_general_setting_option');
		register_setting('mwb_wwaylf_custom_text','mwb_wwaylf_custom_setting_option');
		register_setting('mwb_wwaylf_custom_css','mwb_wwaylf_custom_css_option');
	}


	/**
	 * This Function is used to add meta box for purpose
	 *
	 * @since    1.0.0
	 * @name mwb_wwaylf_add_product_meta_box
	 */
	public function mwb_wwaylf_add_product_meta_box($mwb_woo_tabs)
	{
		$mwb_woo_tabs['mwb_what_are_you_tab'] = array(
	        'label'     => __( 'For What Purpose', 'woocommerce-what-are-you-looking-for' ),
	        'target'  => 'mwb-wwaylf-what-are-you-looking'
	    );
	    return $mwb_woo_tabs;
	}


	/**
	 * This Function is used to add html in meta box of purpose
	 *
	 * @since    1.0.0
	 * @name mwb_wwaylf_what_product_tab_content
	 */
	public function mwb_wwaylf_what_product_tab_content()
	{
		?>
			<div id="mwb-wwaylf-what-are-you-looking" class="panel woocommerce_options_panel">
				<div class="options_group">
		<?php
			global $post;
			woocommerce_wp_textarea_input( array(
				'id'                => 'mwb_wwaylf_what',
				'label'             => __( 'Enter purpose for buying this product', 'woocommerce-what-are-you-looking-for' ),
				'value'             => get_post_meta($post->ID,'mwb_wwaylf_product_purpose',true),
				'desc_tip'          => true,
				'placeholder'		=> __( 'Write multiple purpose separated by comma', 'woocommerce-what-are-you-looking-for' ),
				'description'       => __( 'Write multiple purpose separated by comma', 'woocommerce-what-are-you-looking-for' )
			) );
			woocommerce_wp_textarea_input( array(
				'id'                => 'mwb_wwaylf_what_user_admin',
				'label'             => __( 'Purpose Entered By User', 'woocommerce-what-are-you-looking-for' ),
				'value'             => get_post_meta($post->ID,'mwb_wwaylf_product_purpose_user',true),
				'desc_tip'          => true,
				'placeholder'		=> __( 'No purpose found', 'woocommerce-what-are-you-looking-for' ),
				'description'       => __( 'These Purpose are enterd by users and you can update this purpose' )
			) );
		?>
				</div>
			</div>
		<?php
	}


	/**
	 * This Function is used to save values of meta box of purpose
	 *
	 * @since    1.0.0
	 * @name mwb_wwaylf_product_data_save
	 */
	public function mwb_wwaylf_product_data_save($post_id,$post)
	{
		if ( empty( $_POST['woocommerce_meta_nonce'] ) || ! wp_verify_nonce( $_POST['woocommerce_meta_nonce'], 'woocommerce_save_data' ) ) {
			return;
		}
		if($post->post_type != 'product')
		{
			return;
		}
		if(isset($_POST['mwb_wwaylf_what']))
		{
			update_post_meta($post_id,'mwb_wwaylf_product_purpose',sanitize_text_field($_POST['mwb_wwaylf_what']));
		}
		if(isset($_POST['mwb_wwaylf_what_user_admin']))
		{
			update_post_meta($post_id,'mwb_wwaylf_product_purpose_user',sanitize_text_field($_POST['mwb_wwaylf_what_user_admin']));
		}

	}

}
