<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://makewebbetter.com
 * @since      1.0.0
 *
 * @package    Woocommerce_What_Are_You_Looking_For
 * @subpackage Woocommerce_What_Are_You_Looking_For/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Woocommerce_What_Are_You_Looking_For
 * @subpackage Woocommerce_What_Are_You_Looking_For/includes
 * @author     MakeWebBetter <webmaster@makewebbetter.com>
 */
class Woocommerce_What_Are_You_Looking_For {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Woocommerce_What_Are_You_Looking_For_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		$this->plugin_name = 'woocommerce-what-are-you-looking-for';
		$this->version = '1.0.0';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Woocommerce_What_Are_You_Looking_For_Loader. Orchestrates the hooks of the plugin.
	 * - Woocommerce_What_Are_You_Looking_For_i18n. Defines internationalization functionality.
	 * - Woocommerce_What_Are_You_Looking_For_Admin. Defines all hooks for the admin area.
	 * - Woocommerce_What_Are_You_Looking_For_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-woocommerce-what-are-you-looking-for-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-woocommerce-what-are-you-looking-for-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-woocommerce-what-are-you-looking-for-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-woocommerce-what-are-you-looking-for-public.php';

		$this->loader = new Woocommerce_What_Are_You_Looking_For_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Woocommerce_What_Are_You_Looking_For_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Woocommerce_What_Are_You_Looking_For_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Woocommerce_What_Are_You_Looking_For_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_action('admin_menu',$plugin_admin,'mwb_wwaylf_admin_menu');
		$this->loader->add_action('admin_init',$plugin_admin,'mwb_wwaylf_register_setting');
		$this->loader->add_filter('woocommerce_product_data_tabs',$plugin_admin,'mwb_wwaylf_add_product_meta_box');
		$this->loader->add_filter('woocommerce_product_data_panels',$plugin_admin,'mwb_wwaylf_what_product_tab_content');
		$this->loader->add_action('save_post',$plugin_admin,'mwb_wwaylf_product_data_save',10,2);

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Woocommerce_What_Are_You_Looking_For_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles');
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		$this->loader->add_action( 'woocommerce_archive_description', $plugin_public, 'mwb_wwaylf_insert_prod_for_empty_search');
		$this->loader->add_action( 'woocommerce_after_main_content', $plugin_public, 'mwb_wwaylf_insert_prod_for_empty_search_reset_query');
		$this->loader->add_filter( 'woocommerce_page_title', $plugin_public, 'mwb_wwaylf_change_search_text');
		$this->loader->add_action( 'woocommerce_single_product_summary', $plugin_public, 'mwb_wwaylf_count_product_view' );
		$this->loader->add_action('init', $plugin_public, 'mwb_wwaylf_register_session');
		$this->loader->add_action('wp_print_footer_scripts', $plugin_public, 'mwb_wwaylf_check_user_event');
		$this->loader->add_filter('woocommerce_add_to_cart',$plugin_public,'mwb_wwaylf_purpose_tab');

		$this->loader->add_action('woocommerce_single_product_summary',$plugin_public,'mwb_wwaylf_product_data_purpose_save');
		
		$this->loader->add_action('wp',$plugin_public,'mwb_wwaylf_product_data_purpose_save_ajax');
		$this->loader->add_action('woocommerce_thankyou',$plugin_public,'mwb_wwaylf_unset_looking');

	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Woocommerce_What_Are_You_Looking_For_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
