<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://makewebbetter.com
 * @since      1.0.0
 *
 * @package    Woocommerce_What_Are_You_Looking_For
 * @subpackage Woocommerce_What_Are_You_Looking_For/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Woocommerce_What_Are_You_Looking_For
 * @subpackage Woocommerce_What_Are_You_Looking_For/public
 * @author     MakeWebBetter <webmaster@makewebbetter.com>
 */
class Woocommerce_What_Are_You_Looking_For_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Check product search status.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      bool    $mwb_wwaylf_search_status  Check weather product is found or not.
	 */
	private $mwb_wwaylf_search_status = true;

	/**
	 * General Setting.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      bool    $mwb_wwaylf_get_general_setting  General Setting for search product.
	 */

	private $mwb_wwaylf_get_general_setting = true;
	private $mwb_wwaylf_get_custom_text;
	private $mwb_wwaylf_get_custom_css;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->mwb_wwaylf_get_general_setting = get_option('mwb_wwaylf_general_setting_option');
		$this->mwb_wwaylf_get_custom_text = get_option('mwb_wwaylf_custom_setting_option');
		$this->mwb_wwaylf_get_custom_css = get_option('mwb_wwaylf_custom_css_option');

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Woocommerce_What_Are_You_Looking_For_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Woocommerce_What_Are_You_Looking_For_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/woocommerce-what-are-you-looking-for-public.css', array(), $this->version, 'all' );
		?>
			<style type="text/css">
				<?php
					echo $this->mwb_wwaylf_get_custom_css['css'];
				?>
			</style>
		<?php

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Woocommerce_What_Are_You_Looking_For_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Woocommerce_What_Are_You_Looking_For_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/woocommerce-what-are-you-looking-for-public.js', array( 'jquery' ), $this->version, false );
		$mwb_wwaylf_ajax_data = array(
			'text_for_can_you' => isset($this->mwb_wwaylf_get_custom_text['custom_text_ask']) && !empty($this->mwb_wwaylf_get_custom_text['custom_text_ask']) ? $this->mwb_wwaylf_get_custom_text['custom_text_ask'] : '<h3>'.__( 'Can You Tell for what purpose you are buying this product.' , 'woocommerce-what-are-you-looking-for' ).'</h3><h4>'.__( 'This will help other user for buying this product' , 'woocommerce-what-are-you-looking-for' ).'</h4>',
			'text_for_submit' => __( 'Submit' , 'woocommerce-what-are-you-looking-for' ),
			'backgrnd_img' => MWB_WWAYLF_URL.'/public/images/can_popup.jpg',
			'mwb_wwaylf_nonce' => wp_nonce_field('mwb_wwyalf_prod_purpose','mwb_wwyalf_product_pur_nonce')
		);
		wp_localize_script($this->plugin_name, 'mwb_wwaylf_ajax_obj', $mwb_wwaylf_ajax_data);

	}


	/**
	 * This Function is used to check search result is empty
	 *
	 * @since    1.0.0
	 * @name mwb_wwaylf_change_search_text
	 * return string
	 */
	public function mwb_wwaylf_change_search_text($page_title)
	{
		if ( !isset($_GET['mwb_smart_search']) && !have_posts() && ! woocommerce_product_subcategories( array( 'before' => woocommerce_product_loop_start( false ), 'after' => woocommerce_product_loop_end( false ) ) ) )
		{
			$this->mwb_wwaylf_search_status = false;
		}
		return $page_title;
	}


	/**
	 * This Function is used to show product(top rated,most visited,most ordered) on empty search
	 *
	 * @since    1.0.0
	 * @name mwb_wwaylf_insert_prod_for_empty_search 
	 */
	public function mwb_wwaylf_insert_prod_for_empty_search()
	{

		if ( !$this->mwb_wwaylf_search_status  || isset($_GET['mwb_smart_search']) )
		{
			$paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
			if(isset($_GET['mwb_smart_search']))
			{
				$mwb_wwaylf_query_args = array(
						'post_type' => 'product',
						'post_status' => 'publish',
				        'ignore_sticky_posts' => 1,
				        'posts_per_page' => -1,
				        'paged' =>$paged,
				        'meta_query' => array(
				        	'relation' => 'OR',
				        	array(
		    					'key'=>'mwb_wwaylf_product_purpose',
		    					'value'=>sanitize_text_field($_GET['s']),
		    					'compare'=>'LIKE',
				        	),
				        	array(
		    					'key'=>'mwb_wwaylf_product_purpose_user',
		    					'value'=>sanitize_text_field($_GET['s']),
		    					'compare'=>'LIKE',
				        	)
				        )
				    );
				$mwb_smart_search_status = true;
			}
			else
			{
				if(isset($this->mwb_wwaylf_get_general_setting['prod_search']) && !empty($this->mwb_wwaylf_get_general_setting['prod_search']))
				{
					if($this->mwb_wwaylf_get_general_setting['prod_search'] == 'most_ordered')
					{
						$mwb_wwaylf_query_args = array(
							'post_type' => 'product',
							'post_status' => 'publish',
					        'ignore_sticky_posts' => 1,
					        'posts_per_page' => -1,
					        'paged' =>$paged,
					        'meta_key'=> 'total_sales',
					        'meta_query' => array(
					        	array(
			    					'key'=> 'total_sales',
			    					'value'=> isset($this->mwb_wwaylf_get_general_setting['most_order_max']) && !empty($this->mwb_wwaylf_get_general_setting['most_order_max']) ? $this->mwb_wwaylf_get_general_setting['most_order_max'] : 5,
			    					'compare'=>'>=',
			    					'type' => 'numeric'
					        	)
					        )
					    );
					}
					elseif ($this->mwb_wwaylf_get_general_setting['prod_search'] == 'top_rated') 
					{
						$mwb_wwaylf_query_args = array(
							'post_type' => 'product',
							'post_status' => 'publish',
					        'ignore_sticky_posts' => 1,
					        'posts_per_page' => -1,
					        'paged' => $paged,
					        'meta_key' =>'_wc_average_rating',
					        'meta_query' => array(
					        	'key' =>'_wc_average_rating',
					        	'value' => isset($this->mwb_wwaylf_get_general_setting['most_rated_max']) && !empty($this->mwb_wwaylf_get_general_setting['most_rated_max']) ? $this->mwb_wwaylf_get_general_setting['most_rated_max'] : 3,
					        	'compare' => '>=',
					        	'type' => 'numeric'
					        )
					    );
					}
					elseif ($this->mwb_wwaylf_get_general_setting['prod_search'] == 'most_visited') 
					{
						$mwb_wwaylf_query_args = array(
							'post_type' => 'product',
							'post_status' => 'publish',
					        'ignore_sticky_posts' => 1,
					        'posts_per_page' => -1,
					        'paged' =>$paged,
					        'meta_key' => 'mwb_wwaylf_prod_view',
					        'meta_query' =>array(
					        	'key' => 'mwb_wwaylf_prod_view',
					        	'value' => isset($this->mwb_wwaylf_get_general_setting['most_visit_max']) && !empty($this->mwb_wwaylf_get_general_setting['most_visit_max']) ? $this->mwb_wwaylf_get_general_setting['most_visit_max'] : 10,
					        	'compare' => '>=',
					        	'type' => 'numeric'
					        )
					    );
					}
				}
			}

			if(isset($_GET['orderby']))
			{
				if($_GET['orderby']== 'popularity')
				{
					$mwb_ord_by = array( 
						'meta_key' => 'total_sales',
						'orderby' => 'meta_value',
			        	'order'  => 'DESC');
				}
				if($_GET['orderby']== 'rating')
				{
					$mwb_ord_by = array( 
						'meta_key' => '_wc_average_rating',
						'orderby' => 'meta_value_num',
			        	'order'  => 'DESC');
				}
				if($_GET['orderby']== 'date')
				{
					$mwb_ord_by = array( 
						'orderby' => 'date',
			        	'order'  => 'DESC');
				}
				if($_GET['orderby']== 'price')
				{
					$mwb_ord_by = array( 
						'meta_key' => '_price',
						'orderby' => 'meta_value_num',
			        	'order'  => 'ASC');
				}
				if($_GET['orderby']== 'price-desc')
				{
					$mwb_ord_by = array( 
						'meta_key' => '_price',
						'orderby' => 'meta_value_num',
			        	'order'  => 'DESC');
				}
				if($_GET['orderby']== 'menu_order')
				{
					$mwb_ord_by = array( 
						'orderby' => 'menu_order',
			        	'order'  => 'DESC');
				}
			}
			else
			{
				$mwb_ord_by = array( 
						'orderby' => 'menu_order',
			        	'order'  => 'DESC');
			}
			if(isset($mwb_wwaylf_query_args) && !empty($mwb_wwaylf_query_args))
			{
				$mwb_wwaylf_query_post_args = array_merge($mwb_wwaylf_query_args,$mwb_ord_by);
				$GLOBALS['wp_query'] = new WP_Query($mwb_wwaylf_query_post_args);
				if(!empty($GLOBALS['wp_query']) && $GLOBALS['wp_query']->post_count > 0)
				{
					if( isset($this->mwb_wwaylf_get_general_setting['custom_text']) && !empty($this->mwb_wwaylf_get_general_setting['custom_text'])):
					?>
						<p class="woocommerce-info"><?php echo $this->mwb_wwaylf_get_general_setting['custom_text']; ?></p>
					<?php
					endif;
				}
				elseif ( isset($mwb_smart_search_status) ) 
				{
					wp_reset_query();
					if(isset($this->mwb_wwaylf_get_general_setting['prod_search']) && !empty($this->mwb_wwaylf_get_general_setting['prod_search']) && !have_posts() && ! woocommerce_product_subcategories( array( 'before' => woocommerce_product_loop_start( false ), 'after' => woocommerce_product_loop_end( false ) ) ) )
					{
						if($this->mwb_wwaylf_get_general_setting['prod_search'] == 'most_ordered')
						{
							$mwb_wwaylf_query_args = array(
								'post_type' => 'product',
								'post_status' => 'publish',
						        'ignore_sticky_posts' => 1,
						        'posts_per_page' => -1,
						        'paged' =>$paged,
						        'meta_key'=> 'total_sales',
						        'meta_query' => array(
						        	array(
				    					'key'=> 'total_sales',
				    					'value'=> isset($this->mwb_wwaylf_get_general_setting['most_order_max']) && !empty($this->mwb_wwaylf_get_general_setting['most_order_max']) ? $this->mwb_wwaylf_get_general_setting['most_order_max'] : 5,
				    					'compare'=>'>=',
				    					'type' => 'numeric'
						        	)
						        )
						    );
						}
						elseif ($this->mwb_wwaylf_get_general_setting['prod_search'] == 'top_rated') 
						{
							$mwb_wwaylf_query_args = array(
								'post_type' => 'product',
								'post_status' => 'publish',
						        'ignore_sticky_posts' => 1,
						        'posts_per_page' => -1,
						        'paged' => $paged,
						        'meta_key' =>'_wc_average_rating',
						        'meta_query' => array(
						        	'key' =>'_wc_average_rating',
						        	'value' => isset($this->mwb_wwaylf_get_general_setting['most_rated_max']) && !empty($this->mwb_wwaylf_get_general_setting['most_rated_max']) ? $this->mwb_wwaylf_get_general_setting['most_rated_max'] : 3,
						        	'compare' => '>=',
						        	'type' => 'numeric'
						        )
						    );
						}
						elseif ($this->mwb_wwaylf_get_general_setting['prod_search'] == 'most_visited') 
						{
							$mwb_wwaylf_query_args = array(
								'post_type' => 'product',
								'post_status' => 'publish',
						        'ignore_sticky_posts' => 1,
						        'posts_per_page' => -1,
						        'paged' =>$paged,
						        'meta_key' => 'mwb_wwaylf_prod_view',
						        'meta_query' =>array(
						        	'key' => 'mwb_wwaylf_prod_view',
						        	'value' => isset($this->mwb_wwaylf_get_general_setting['most_visit_max']) && !empty($this->mwb_wwaylf_get_general_setting['most_visit_max']) ? $this->mwb_wwaylf_get_general_setting['most_visit_max'] : 10,
						        	'compare' => '>=',
						        	'type' => 'numeric'
						        )
						    );
						}
						if(isset($_GET['orderby']))
						{
							if($_GET['orderby']== 'popularity')
							{
								$mwb_ord_by = array( 
									'meta_key' => 'total_sales',
									'orderby' => 'meta_value',
						        	'order'  => 'DESC');
							}
							if($_GET['orderby']== 'rating')
							{
								$mwb_ord_by = array( 
									'meta_key' => '_wc_average_rating',
									'orderby' => 'meta_value_num',
						        	'order'  => 'DESC');
							}
							if($_GET['orderby']== 'date')
							{
								$mwb_ord_by = array( 
									'orderby' => 'date',
						        	'order'  => 'DESC');
							}
							if($_GET['orderby']== 'price')
							{
								$mwb_ord_by = array( 
									'meta_key' => '_price',
									'orderby' => 'meta_value_num',
						        	'order'  => 'ASC');
							}
							if($_GET['orderby']== 'price-desc')
							{
								$mwb_ord_by = array( 
									'meta_key' => '_price',
									'orderby' => 'meta_value_num',
						        	'order'  => 'DESC');
							}
							if($_GET['orderby']== 'menu_order')
							{
								$mwb_ord_by = array( 
									'orderby' => 'menu_order',
						        	'order'  => 'DESC');
							}
						}
						else
						{
							$mwb_ord_by = array( 
									'orderby' => 'menu_order',
						        	'order'  => 'DESC');
						}
						if(isset($mwb_wwaylf_query_args) && !empty($mwb_wwaylf_query_args))
						{
							$mwb_wwaylf_query_post_args = array_merge($mwb_wwaylf_query_args,$mwb_ord_by);
							$GLOBALS['wp_query'] = new WP_Query($mwb_wwaylf_query_post_args);
							if(!empty($GLOBALS['wp_query']) && $GLOBALS['wp_query']->post_count > 0)
							{
								if( isset($this->mwb_wwaylf_get_general_setting['custom_text']) && !empty($this->mwb_wwaylf_get_general_setting['custom_text'])):
								?>
									<p class="woocommerce-info"><?php echo $this->mwb_wwaylf_get_general_setting['custom_text']; ?></p>
								<?php
								endif;
							}
						}
					}
				}
			}
		}
	}

	/**
	 * This Function is used to reset query
	 *
	 * @since    1.0.0
	 * @name mwb_wwaylf_insert_prod_for_empty_search_reset_query 
	 */
	public function mwb_wwaylf_insert_prod_for_empty_search_reset_query()
	{
		if($this->mwb_wwaylf_search_status === false)
		{
			wp_reset_query();
		}
	}


	/**
	 * This Function is used to count product views
	 *
	 * @since    1.0.0
	 * @name mwb_wwaylf_count_product_view
	 */
	public function mwb_wwaylf_count_product_view()
	{
		$mwb_wwaylf_get_view = get_post_meta(get_the_ID(),'mwb_wwaylf_prod_view',true);
		if( $mwb_wwaylf_get_view )
		{
			$mwb_wwaylf_get_view++;
			update_post_meta(get_the_ID(),'mwb_wwaylf_prod_view',$mwb_wwaylf_get_view);
		}
		else
		{
			$mwb_wwaylf_get_view = 1;
			update_post_meta(get_the_ID(),'mwb_wwaylf_prod_view',$mwb_wwaylf_get_view);
		}
	}


	/**
	 * This Function is used to set session for what are you looking
	 *
	 * @since    1.0.0
	 * @name mwb_wwaylf_register_session
	 */
	public function mwb_wwaylf_register_session()
	{
		if( !session_id() )
		{
			session_start();
			if( !isset($_SESSION['mwb_wwaylf_track_user']) )
			{
				$_SESSION['mwb_wwaylf_track_user']=array('mwb_start'=>current_time('Y-m-d H:i:s'));
			}
		}
		else
        {
            if( !isset($_SESSION['mwb_wwaylf_track_user']) )
			{
				$_SESSION['mwb_wwaylf_track_user']=array('mwb_start'=>current_time('Y-m-d H:i:s'));
			}
        }
	}


	/**
	 * This Function is used to check user event and show popup what are you looking
	 *
	 * @since    1.0.0
	 * @name mwb_wwaylf_check_user_event
	 */
	public function mwb_wwaylf_check_user_event()
	{
		if(empty(WC()->cart->get_cart()) && isset($_SESSION['mwb_wwaylf_track_user']))
		{
			if( isset( $this->mwb_wwaylf_get_general_setting['second'] ) )
			{
				$mwb_showing_status = (strtotime($_SESSION['mwb_wwaylf_track_user']['mwb_start']) + (int)$this->mwb_wwaylf_get_general_setting['second']) < strtotime(current_time('Y-m-d H:i:s')) ? true : false;
				if($mwb_showing_status && empty($_GET)):
				?>
				<div class="mwb_wwaylf_full">
					<div id="mwb_wwaylf_popup">
						<div class="mwb_wwaylf_close">
							<a href="#">
								<i class="fa fa-times" aria-hidden="true"></i>
							</a>
						</div>
					    <div class="mwb_wwaylf_title">
					    <?php
					    if(isset($this->mwb_wwaylf_get_custom_text['custom_text']) && !empty($this->mwb_wwaylf_get_custom_text['custom_text'])):
					    	echo $this->mwb_wwaylf_get_custom_text['custom_text'];
					    else:
					    ?>
				       		<h3><?php _e('WHAT ARE YOU','woocommerce-what-are-you-looking-for');?></h3>
					    	<h4><?php _e('LOOKING FOR?','woocommerce-what-are-you-looking-for');?></h4>
					    <?php
					    endif;
					    ?>
					     </div>
				      	<form role="search" method="get" action="<?php echo esc_url( home_url( '/' ) ); ?>">
						    <div class="mwb_wwaylf_search_sec">
						        <div class="input-group">

							          <input type="text" required="required" class="form-control" name="s" placeholder="<?php _e('Search for...','woocommerce-what-are-you-looking-for');?>">
							          <input type="hidden" name="post_type" value="product">
							          <input type="hidden" name="mwb_smart_search" value="product">
							          <span class="input-group-btn">
							            <button class="btn btn-default" type="submit"><i class="fa fa-search" aria-hidden="true"></i></button>
							          </span>
						        </div>
					      	</div><!-- search_sec -->
				      	</form>
				      	<div class="mwb_wwaylf_popup_bg">
				        	<img src="<?php echo MWB_WWAYLF_URL;?>public/images/popup.png" class="img-responsive">
				      	</div><!-- popup_bg -->
			    	</div><!-- popup -->
				</div>
				<?php
				endif;
			}
		}
	}


	/**
	 * This Function is used to save pupose of product entered by user
	 *
	 * @since    1.0.0
	 * @name mwb_wwaylf_product_data_purpose_save
	 */
	public function mwb_wwaylf_product_data_purpose_save()
	{
		if(isset($_POST['mwb_wwyalf_submit']) && isset($_POST['mwb_wwaylf_product_purpose_user']) && isset($_POST['mwb_wwyalf_product_pur_nonce']))
		{
			if(wp_verify_nonce($_POST['mwb_wwyalf_product_pur_nonce'],'mwb_wwyalf_prod_purpose'))
			{
				$mwb_wwyalf_user_perpose = get_post_meta(get_the_ID(),'mwb_wwaylf_product_purpose_user',true);
				$mwb_wwyalf_user_perpose_vali = explode(' ', $mwb_wwyalf_user_perpose);
				if( count( $mwb_wwyalf_user_perpose_vali ) < 150 && !empty($_POST['mwb_wwaylf_product_purpose_user']))
				{
					$mwb_wwyalf_user_perpose .= ' '.sanitize_text_field($_POST['mwb_wwaylf_product_purpose_user']);
					update_post_meta(get_the_ID(),'mwb_wwaylf_product_purpose_user',$mwb_wwyalf_user_perpose);
				}
			}
		}
	}

	/**
	 * This Function is used to save pupose of product entered by user on shop page
	 *
	 * @since    1.0.0
	 * @name mwb_wwaylf_product_data_purpose_save_ajax
	 */
	public function mwb_wwaylf_product_data_purpose_save_ajax()
	{
		if(isset($_POST['mwb_wwyalf_submit']) && isset($_POST['mwb_wwaylf_product_purpose_user']) && isset($_POST['mwb_wwyalf_product_pur_nonce']) && isset($_POST['mwb_wwaylf_product_id']))
		{
			if(wp_verify_nonce($_POST['mwb_wwyalf_product_pur_nonce'],'mwb_wwyalf_prod_purpose'))
			{
				$mwb_wwyalf_user_perpose = get_post_meta($_POST['mwb_wwaylf_product_id'],'mwb_wwaylf_product_purpose_user',true);
				$mwb_wwyalf_user_perpose_vali = explode(' ', $mwb_wwyalf_user_perpose);
				if( count( $mwb_wwyalf_user_perpose_vali ) < 150 && !empty($_POST['mwb_wwaylf_product_purpose_user']))
				{
					$mwb_wwyalf_user_perpose .= ' '.sanitize_text_field($_POST['mwb_wwaylf_product_purpose_user']);
					update_post_meta($_POST['mwb_wwaylf_product_id'],'mwb_wwaylf_product_purpose_user',$mwb_wwyalf_user_perpose);
				}
			}
		}
	}


	/**
	 * This Function is used to show popup of purpose tab
	 *
	 * @since    1.0.0
	 * @name mwb_wwaylf_purpose_tab
	 */
	public function mwb_wwaylf_purpose_tab()
	{
		if(!isset($_GET['wc-ajax'])):
		?>
			<div class="mwb_wwaylf_full">
		        <div id="mwb_wwaylf_prod_purpose">
			        <div class="mwb_wwaylf_close">
			          <a href="#">
			            <i class="fa fa-times" aria-hidden="true"></i>
			          </a>
			        </div>
			        <div class="mwb_wwaylf_title">
			        	<?php
				        	if(isset($this->mwb_wwaylf_get_custom_text['custom_text_ask']) && !empty($this->mwb_wwaylf_get_custom_text['custom_text_ask'])):
				        		echo $this->mwb_wwaylf_get_custom_text['custom_text_ask'];
			        		else:
			        	?>
				             	<h3><?php _e( 'Can You Tell for what purpose you are buying this product.' , 'woocommerce-what-are-you-looking-for' )?></h3>
				             	<h4><?php _e( 'This will help other user for buying this product' , 'woocommerce-what-are-you-looking-for' )?></h4>
			            <?php
			            	endif;
			            ?>
			        </div>
		            <form method="post" action="">
		                <div class="mwb_wwaylf_email_sec">
		                    <div class="form-group">
			                    <input type="text" required="required" name="mwb_wwaylf_product_purpose_user" id="mwb_wwaylf_product_purpose_user" class="form-control">
									<?php
										wp_nonce_field('mwb_wwyalf_prod_purpose','mwb_wwyalf_product_pur_nonce');
									?>
		                    </div>
		                	<div class="form-group">
		                    	<button type="submit" name="mwb_wwyalf_submit" class="btn btn-default"><?php _e('Submit', 'woocommerce-what-are-you-looking-for');?></button>
		                  	</div>
		                </div><!-- search_sec -->
		            </form>
		        </div><!-- popup -->
	      	</div>
		<?php
		endif;
	}


	/**
	 * This Function is used to unset session of what are you looking
	 *
	 * @since    1.0.0
	 * @name mwb_wwaylf_unset_looking
	 */
	public function mwb_wwaylf_unset_looking()
	{
		if(isset($_SESSION['mwb_wwaylf_track_user']))
		{
			unset($_SESSION['mwb_wwaylf_track_user']);
		}
	}

}
