<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              http://makewebbetter.com
 * @since             1.0.0
 * @package           Woocommerce_What_Are_You_Looking_For
 *
 * @wordpress-plugin
 * Plugin Name:       WooCommerce Sale Booster - What Are You Looking For
 * Plugin URI:        http://makewebbetter.com
 * Description:       This plugin is for saving the customers time for searching anything on shop page. Here we provide the popup window for customer when the customer is not found his/her matching product so we show our products in customer.
 * Version:           1.0.3
 * Author:            20script
 * Author URI:        http://www.20script.ir
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       woocommerce-what-are-you-looking-for
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

$mwb_wwaylf_woo_activated = true;

//check woocommerce activated or not
if( function_exists('is_multisite') && is_multisite())
{
	include_once(ABSPATH. 'wp-admin/includes/plugin.php');
	if( !is_plugin_active('woocommerce/woocommerce.php'))
	{
		$mwb_wwaylf_woo_activated = false;
	}
}
else
{
	if( !in_array('woocommerce/woocommerce.php',apply_filters('active_plugins',get_option('active_plugins'))))
	{
		$mwb_wwaylf_woo_activated = false;
	}
}

if($mwb_wwaylf_woo_activated)
{

	define('MWB_WWAYLF_DIRPATH', plugin_dir_path( __FILE__ ));
	define('MWB_WWAYLF_URL', plugin_dir_url( __FILE__ ));
	define('MWB_WWAYLF_HOME_URL', home_url());

	add_action('plugins_loaded','mwb_wwaylf_load_woocommerce');
	add_filter ( 'plugin_action_links','mwb_wwaylf_admin_settings',10,2);
	add_action('plugins_loaded', 'mwb_wwaylf_load_plugin_textdomain');

	/**
	 * This function is used to load text domain'.
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link http://www.makewebbetter.com/
	 */
	function mwb_wwaylf_load_plugin_textdomain()
	{
		$domain = "woocommerce-what-are-you-looking-for";
		$locale = apply_filters( 'plugin_locale', get_locale(), $domain );
		load_textdomain( $domain, MWB_WWAYLF_DIRPATH .'languages/'.$domain.'-' . $locale . '.mo' );
		$var=load_plugin_textdomain( $domain, false, plugin_basename( dirname(__FILE__) ) . '/languages' );
	
	}
	

	/**
	 * This function is used to set url in of setting in plugin row meta
	 * @name mwb_wwaylf_admin_settings
	 * @param $actions, $plugin_file
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link http://www.makewebbetter.com/
	 */
	function mwb_wwaylf_admin_settings($actions, $plugin_file) 
	{
		static $plugin;
		if (! isset ( $plugin )) {
	
			$plugin = plugin_basename ( __FILE__ );
		}
		if ($plugin == $plugin_file) {
			$settings = array (
					'settings' => '<a href="' . home_url ( '/wp-admin/admin.php?page=mwb_what_are_looking_for' ) . '">' . __ ( 'Settings', 'woocommerce-what-are-you-looking-for' ) . '</a>',
			);
			$actions = array_merge ( $settings, $actions );
		}
		return $actions;
	}


	/**
	 * This function is used to load woocommerce and The core plugin class that is used to define internationalization, admin-specific hooks, and public-facing site hooks.
	 * @name mwb_wwaylf_load_woocommerce
	 * @param $actions, $plugin_file
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link http://www.makewebbetter.com/
	 */
	function mwb_wwaylf_load_woocommerce()
	{
		if(function_exists('WC'))
		{
			require plugin_dir_path( __FILE__ ) . 'includes/class-woocommerce-what-are-you-looking-for.php';
			run_woocommerce_what_are_you_looking_for();
		}
	}


	/**
	 * Begins execution of the plugin.
	 *
	 * Since everything within the plugin is registered via hooks,
	 * then kicking off the plugin from this point in the file does
	 * not affect the page life cycle.
	 *
	 * @since    1.0.0
	 */
	function run_woocommerce_what_are_you_looking_for() {

		$plugin = new Woocommerce_What_Are_You_Looking_For();
		$plugin->run();

	}
}
else
{
	add_action('admin_init','mwb_wwaylf_woo_deactivate');
	add_action('admin_notices','mwb_wwaylf_woo_err_notice');
	function mwb_wwaylf_woo_deactivate()
	{
		deactivate_plugins( plugin_basename(__FILE__) );
	}


	/**
	 * Show warning message if woocommerce is not install
	 *
	 * @name mwb_wwaylf_woo_err_notice
	 * @author makewebbetter<webmaster@makewebbetter.com>
	 * @link http://www.makewebbetter.com/
	 */
	function mwb_wwaylf_woo_err_notice()
	{
		?>
			<div class="error notice is-dismissible">
				<p><?php _e( 'Woocommerce is not activated, Please activate Woocommerce first to install WooCommerce Sale Booster - What Are You Looking For.', 'woocommerce-what-are-you-looking-for' ); ?></p>				
			</div>
			<style>
	   			#message{display:none;}
	   		</style>
		<?php
	}
}
